# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('galleryserve', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='gallery',
            name='random',
            field=models.BooleanField(default=False, help_text=b'If selected, the sort numbers will be ignored and your gallery objects will be generated in random order.'),
        ),
    ]



from django.db import models
import PIL
from PIL import ImageOps

class Gallery(models.Model):
    title = models.CharField(max_length=200)
    height = models.IntegerField(blank=True, default=600,
        help_text="Height images should be resized to in pixels")
    width = models.IntegerField(blank=True, default=800,
        help_text="Width images should be resized to in pixels")
    random = models.BooleanField(default=False,
        help_text="If selected, the sort numbers will be ignored and your "
        "gallery objects will be generated in random order.")
    resize = models.BooleanField(default=True,
        help_text="If selected, the dimensions specified above will be used"
        " to scale and crop the uploaded image")
    quality = models.IntegerField(u'Image Quality', default=85, 
        help_text="An integer between 0-100. 100 will result in the largest " 
        "file size.")
    class Meta:
        ordering = ('title',)
        verbose_name_plural = 'galleries'

    def __unicode__(self):
        return u'%s' %(self.title)


class Item(models.Model):
    image = models.ImageField(blank=True, upload_to='galleryserve/images')
    gallery = models.ForeignKey(Gallery, related_name='items')
    alt = models.CharField(max_length=100, blank=True,
        help_text="This will be used for the image alt attribute")
    title = models.CharField(max_length=100, blank=True,
        help_text="This will be used for the image or content title attribute")
    credit = models.CharField(max_length=200, blank=True,
        help_text="Use this field to credit the image or content creator")
    video_url = models.URLField('video url', blank=True, 
        help_text="Enter the url of the video to be embedded")
    url = models.CharField('target url', blank=True, max_length=200,
        help_text="URL to which the image will be linked.")
    content = models.TextField(blank=True, help_text="Use this field to "
        "add html content associated with the item")
    sort = models.IntegerField(default=0,
        help_text="Items will be displayed in their sort order")

    class Meta:
        ordering = ('sort',)

    def __unicode__(self):
        return u'%s' %(self.alt)

    def save(self):
        super(Item, self).save()
        if self.image:
            filename = self.image.path
            image = PIL.Image.open(filename)
            if self.gallery.resize:
                try:
                    width = self.gallery.width
                except:
                    width = 800
                try:
                    height = self.gallery.height
                except:
                    height = 600
                size=(width, height)
                image = ImageOps.fit(image, size, PIL.Image.ANTIALIAS)
            image.save(filename, quality=self.gallery.quality)




# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Gallery.random'
        db.add_column(u'galleryserve_gallery', 'random',
                      self.gf('django.db.models.fields.BooleanField')(default=False),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting field 'Gallery.random'
        db.delete_column(u'galleryserve_gallery', 'random')


    models = {
        u'galleryserve.gallery': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Gallery'},
            'height': ('django.db.models.fields.IntegerField', [], {'default': '600', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'quality': ('django.db.models.fields.IntegerField', [], {'default': '85'}),
            'random': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'resize': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'width': ('django.db.models.fields.IntegerField', [], {'default': '800', 'blank': 'True'})
        },
        u'galleryserve.item': {
            'Meta': {'ordering': "('sort',)", 'object_name': 'Item'},
            'alt': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'content': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'credit': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'gallery': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'items'", 'to': u"orm['galleryserve.Gallery']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'blank': 'True'}),
            'sort': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'video_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'})
        }
    }

    complete_apps = ['galleryserve']


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import galleryserve.models


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Gallery',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=200)),
                ('height', models.IntegerField(default=600, help_text=b'Height images should be resized to in pixels', blank=True)),
                ('width', models.IntegerField(default=800, help_text=b'Width images should be resized to in pixels', blank=True)),
                ('resize', models.BooleanField(default=True, help_text=b'If selected, the dimensions specified above will be used to scale and crop the uploaded image')),
                ('quality', models.IntegerField(default=85, help_text=b'An integer between 0-100. 100 will result in the largest file size.', verbose_name='Image Quality')),
            ],
            options={
                'ordering': ('title',),
                'verbose_name_plural': 'galleries',
            },
        ),
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('image', models.ImageField(upload_to=b'galleryserve/images', blank=True)),
                ('alt', models.CharField(help_text=b'This will be used for the image alt attribute', max_length=100, blank=True)),
                ('title', models.CharField(help_text=b'This will be used for the image or content title attribute', max_length=100, blank=True)),
                ('credit', models.CharField(help_text=b'Use this field to credit the image or content creator', max_length=200, blank=True)),
                ('video_url', models.URLField(help_text=b'Enter the url of the video to be embedded', verbose_name=b'video url', blank=True)),
                ('url', models.CharField(help_text=b'URL to which the image will be linked.', max_length=200, verbose_name=b'target url', blank=True)),
                ('content', models.TextField(help_text=b'Use this field to add html content associated with the item', blank=True)),
                ('sort', models.IntegerField(default=0, help_text=b'Items will be displayed in their sort order')),
                ('gallery', models.ForeignKey(related_name='items', to='galleryserve.Gallery')),
            ],
            options={
                'ordering': ('sort',),
            },
        ),
    ]
